@@ -176,19 +176,19 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     return []
 
 def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,**kwargs):
-    return asyncio.run(async_call_rate_limiter(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs))
+    return call_async_function('async_call_rate_limiter',method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs)
 
 def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,**kwargs):
-    return asyncio.run(async_make_rate_limited_call(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs))
+    return call_async_function('async_make_rate_limited_call',method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs)
 
 def call_solcatcher_py(endpoint,*args,**kwargs):
-    return asyncio.run(async_call_solcatcher_py(endpoint,*args,**kwargs))
+    return call_async_function('async_call_solcatcher_py',endpoint,*args,**kwargs)
 
 def call_solcatcher_ts(endpoint,*args,**kwargs):
-    return asyncio.run(async_call_solcatcher_ts(endpoint,*args,**kwargs))
+    return call_async_function('async_call_solcatcher_ts',endpoint,*args,**kwargs)
 
 def call_solcatcher_db(endpoint,*args, **kwargs):
-    return asyncio.run(async_call_solcatcher_db(endpoint,*args,**kwargs))
+    return call_async_function('async_call_solcatcher_db',endpoint,*args,**kwargs)
 
 
 
