@@ -3,6 +3,14 @@ from abstract_utilities import eatAll
 from abstract_security import get_env_value
 from abstract_apis import get_headers,get_response
 import requests
+async def call_async_function(func, *args, **kwargs):
+    """Helper function to call async functions in sync or async contexts."""
+    if asyncio.isrunning():
+        # If an event loop is already running, use await
+        return await func(*args, **kwargs)
+    else:
+        # If no event loop is running, use asyncio.run()
+        return await asyncio.run(func(*args, **kwargs))
 def getSolcatcherUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io')
 def getSolcatcherPairCatchUrl(endpoint=None):
